@@ -21,21 +21,21 @@ def sol_ode(model, var0, t, param):
     Returns:
         ar (array): Array containing the value of var for each desired time in t, with the initial value var0 in the first row
     """
+    dt = t[1]-t[0]
     if isinstance(param,list):
-        if (len(param) == 1):
-            param = param[0]
-        else: pass
+        param = np.array(param)
     else: pass
 
     if isinstance(var0,list):
-        if (len(var0) == 1) :
-            var0 = var0[0]
-        else: pass
+        var0 = np.array(var0)
     else: pass
     
-    results = ow.odeintw(model, y0=var0, t=t, args=(param,))
+    results = ow.odeintw(model, y0=var0, t=t, args=(param,),hmax = dt)
     
-    out = model(var0, t, param) #this is a workaround, so in the case of 1 variable and n CSTRs the result does not get flipped
+    try:
+        out = model(var0, t, param) #this is a workaround, so in the case of 1 variable and n CSTRs the result does not get flipped
+    except ValueError:
+        out = (1,1)
     
     if isinstance(out, tuple):
         m = int(np.shape(var0)[0])
